:root {
  /* Add Font Awesome 5 icon and color for todo */
  --pst-icon-clipboard-list: '\f46d';
  --pst-icon-admonition-todo: var(--pst-icon-clipboard-list);
  --pst-color-admonition-todo: 161, 46, 233;
  --target-color: #b9ee9e;
  --codeblock-color: #aad993;
}

.visuallyhidden {
  display: none;
}

pre {
  border-radius: 0;
  background-color: white;
  box-shadow: none;
}

a,
a:visited,
main.bd-content #main-content a,
main.bd-content #main-content a:visited {
  color: #2980b9;
}

a:hover,
main.bd-content #main-content a:hover {
  color: #1a567e;
  text-decoration: none;
}

ul {
  list-style-type: square;
}

ul li>p {
  margin-bottom: 0.3rem;
}

ol li>p {
  margin-bottom: 0.3rem;
}

img {
  margin: 1rem 0;
}

figure img,
img.figure,
.figure img {
  box-shadow: 0 6px 24px 0 rgba(153, 153, 153, 0.3);
}

.sidebar img.logo {
  box-shadow: none;
  width: 200px;
  margin-bottom: 1rem;
}

img.inline {
  margin: 0;
  height: 1em;
}

span.linenos {
  padding-right: 1em;
}

p.ploneorglink img {
  vertical-align: bottom;
}

dt:target,
span.highlighted,
ul.search li span.highlighted {
  background-color: var(--target-color);
}

.bd-sidebar .nav ul {
  padding: 0 0 0 1rem;
}

.bd-sidebar .nav .toctree-checkbox~label i {
  transform: rotate(90deg);
}

.bd-sidebar .nav .toctree-checkbox:checked~label i {
  transform: rotate(0deg);
}

.toctree-wrapper .caption {
  font-weight: bold;
  font-size: 1.2em;
  margin-top: 3rem;
}

.toctree-wrapper ul {
  list-style: none;
}

section:not(#glossary) h1~dl {
  display: grid;
  grid-template-columns: max-content auto;
}

section:not(#glossary) h1~dl dd {
  margin-bottom: unset !important;
}

div.section {
  margin-bottom: 5rem;
}

div.section div.section {
  margin-bottom: 5rem;
}

div.section div.section div.section {
  margin-bottom: 2rem;
}

/* admonitions */
.admonition {
  border-radius: 0;
  border: none;
  border-left: .2rem solid;
  border-left-color: rgba(var(--pst-color-admonition-default), 1);
}

.admonition .admonition-title {
  margin-bottom: 1.5rem !important;
}

/* admonition todo */
.admonition.admonition-todo,
div.admonition.admonition-todo {
  border-color: rgba(var(--pst-color-admonition-todo), 1);
}

.admonition.admonition-todo>.admonition-title,
div.admonition.admonition-todo>.admonition-title {
  background-color: rgba(var(--pst-color-admonition-todo), .1);
}

.admonition.admonition-todo>.admonition-title::before,
div.admonition.admonition-todo>.admonition-title::before {
  color: rgba(var(--pst-color-admonition-todo), 1);
  content: var(--pst-icon-admonition-todo);
}

.admonition-github-only.admonition {
  display: none;
}

/* admonition margin */
.admonition.margin ul,
.admonition.margin ol {
  padding-left: 1rem;
}

.topic {
  padding: 1.5em 1em .5em 1em;
}

.topic-title {
  font-weight: bold;
}


/* Bootstrap */
.btn-primary {
  color: #fff;
  background-color: #2980b9;
  border-color: #2980b9;
}

.btn-primary {
  background-color: #1f86ca;
  border-color: #2980b9;
}

/* Search */

/* Show search form. It is hidden by default. */
#search-documentation,
#search-documentation~form,
#search-documentation~p {
  display: block;
}

#search-form:focus-within #shortcut-page,
.bd-search:focus-within #shortcut {
  display: none;
}

#shortcut-page.input-group-text {
  padding-top: 0;
  padding-bottom: 0;
}

input#q {
  border-radius: .25rem 0 0 .25rem;
}

.form-control:focus {
  box-shadow: none;
  border-width: 2px;
}

ul.search {
  margin-left: 0;
}

p.search-summary {
  margin: 1em 0 2rem 0;
}

#search-results ul {
  list-style-type: none;
  padding-left: 0;
}

#search-results ul li,
ul.search li {
  margin-bottom: 2rem;
  padding: 0;
  background-image: none;
  border-bottom: none;
}

#search-results ul li h3 {
  margin: 0.4rem 0 .5rem;
  font-size: 1.5rem;
}

#search-results ul li .breadcrumbs {
  display: flex;
  flex-direction: row;
  flex-wrap: wrap;
}

#search-results ul li .breadcrumbs a {
  font-weight: normal;
}

#search-results ul li .breadcrumbs .lastbreadcrumb {
  white-space: nowrap;
  display: inline-block;
  max-width: 12rem;
  overflow: hidden;
  /* "overflow"-Wert darf nicht "visible" sein */

  text-overflow: ellipsis;
}

ul.search li p.context {
  margin-left: 0;
}

/* Search form sidebar */

.bd-search {
  font-size: .8rem;
}

.bd-search:focus-within #search-input {
  border-radius: .25rem;
}

#shortcut.input-group-text {
  padding-top: 0;
  padding-bottom: 0;
}

.bd-search input,
.bd-search .input-group-text {
  font-size: .8rem;
  padding-left: .5em;
}

input#search-input {
  padding-left: 2.1875rem;
  border-radius: .25rem 0 0 .25rem;
}

.search-icon {
  position: absolute;
  color: #a4a6a7;
  left: .625rem;
  z-index: 100;
  align-self: center;
}

.input-group-text kbd {
  padding: 0rem 0.4rem;
  font-size: 135%;
}

.pathseparator {
  padding: 0 0.7rem;
}

/* header-article */
div.header-article__label {
  display: flex;
  align-items: center;
  margin: 0 auto 0 1em;
  font-size: 80%;
  overflow: hidden;
  white-space: nowrap;
}

/* submenu */
.bd-toc {
  box-shadow: 0 .2rem .5rem rgba(0, 0, 0, .05), 0 0 .0625rem rgba(0, 0, 0, .1);
}

/* extra sidebar */
div.sidebar:not(.margin) {
  width: 40%;
  float: right;
  clear: right;
  margin: .3rem 0 .3rem 0.5em;
  padding: 2rem 0 1.5rem 1rem !important;
  background-color: rgba(var(--pst-color-admonition-note), .1);
  border: none;
  border-left: 8px rgba(var(--pst-color-admonition-default), 1) solid;
  border-radius: .2rem;
  box-shadow: 0 .2rem .5rem rgba(0, 0, 0, .05), 0 0 .0625rem rgba(0, 0, 0, .1);
}

div.sidebar:not(.margin) .figure {
  margin-top: 0;
  padding-top: 0;
  margin-left: 0;
  padding-left: 0;
}

div.sidebar:not(.margin) img.logo {
  margin-top: 0;
  margin-bottom: .3rem;
}

div.sidebar:not(.margin) p {
  margin-bottom: 0;
}

div.sidebar:not(.margin) p.sidebar-title {
  display: none;
}

div.sidebar:not(.margin) div.topic {
  padding: .5em 0;
  background-color: transparent;
  border: none;
}

div.sidebar:not(.margin) pre {
  margin: .5em 0 1.5em 0;
}

div.sidebar:not(.margin) div[class*="highlight-"] {
  margin-right: .5em;
}

div.sidebar:not(.margin) .admonition {
  margin-right: .5em;
  background-color: #ffffff;
}

@media (min-width:768px) {
  div.sidebar:not(.margin) {
    width: 50%;
    margin-left: 1.5em;
    margin-right: -28%;
  }
}


main.bd-content #main-content dl.simple dt {
  margin-top: .8em;
}

main.bd-content #main-content dl.simple dt:nth-of-type(1) {
  margin-top: 0;
}

main.bd-content #main-content dl.simple dd {
  margin-top: .8em;
}

main.bd-content #main-content dl.simple dt+dd {
  margin-top: 0;
}

.prev-next-bottom {
  margin: 20px 0 30px 0;
}

.prev-next-bottom a.left-prev,
.prev-next-bottom a.right-next {
  padding: 5px 10px;
  border: 1px solid rgba(0, 0, 0, .2);
  max-width: 45%;
  overflow-x: hidden;
  color: rgba(0, 0, 0, .65);
  border-radius: 10px;
}

/* Local navigation */
li.nav-item.toc-entry {
  line-height: 1.25em;
  margin-bottom: 0.25em;
}

span.guilabel,
span.menuselection {
  border: none;
  background: #e7f2fa;
  border-radius: 4px;
  padding: 4px 5px;
  font-size: 90%;
  font-weight: bold;
  font-style: italic;
  white-space: nowrap;
}


/*
 * extensions
 */

/* definitions */
dl.py.function {
  display: block !important;
  margin-bottom: 5rem;
}

dl.py.function>dt {
  background-color: var(--codeblock-color);
  padding: 4px 5px;
}

dl.py.function>dt:target {
  background-color: var(--target-color);
}

dl.field-list>dt {
  padding-left: 0;
}

/* code blocks */
div.viewcode-block:target {
  padding: 10px 10px;
  background-color: var(--codeblock-color);
  border-top: 1px solid var(--codeblock-color);
  border-bottom: 1px solid var(--codeblock-color);
}

/* Fix paragraphs in list items. */
#main-content ol > li > p:nth-child(n+2),
#main-content ul > li > p:nth-child(n+2) {
  margin-top: 1em;
}
